/*
 * FILE:
 *   sdl_gfx_context.hpp
 *
 * PURPOSE:
 *   Implement GfxContext for SDL
 *
 * AUTHOR:
 *   Stephen Thompson <stephen@solarflare.org.uk>
 *
 * COPYRIGHT:
 *   Copyright (C) Stephen Thompson, 2008 - 2024.
 *
 *   This file is part of the "Coercri" software library. Usage of "Coercri"
 *   is permitted under the terms of the Boost Software License, Version 1.0, 
 *   the text of which is displayed below.
 *
 *   Boost Software License - Version 1.0 - August 17th, 2003
 *
 *   Permission is hereby granted, free of charge, to any person or organization
 *   obtaining a copy of the software and accompanying documentation covered by
 *   this license (the "Software") to use, reproduce, display, distribute,
 *   execute, and transmit the Software, and to prepare derivative works of the
 *   Software, and to permit third-parties to whom the Software is furnished to
 *   do so, all subject to the following:
 *
 *   The copyright notices in the Software and this entire statement, including
 *   the above license grant, this restriction and the following disclaimer,
 *   must be included in all copies of the Software, in whole or in part, and
 *   all derivative works of the Software, unless such copies or derivative
 *   works are solely in the form of machine-executable object code generated by
 *   a source language processor.
 *
 *   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *   FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
 *   SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
 *   FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
 *   ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *   DEALINGS IN THE SOFTWARE.
 *
 */

#ifndef COERCRI_SDL_GFX_CONTEXT_HPP
#define COERCRI_SDL_GFX_CONTEXT_HPP

#include "../../gfx/gfx_context.hpp"
#include "../../gfx/rectangle.hpp"

#include <SDL2/SDL.h>

#include <stack>

namespace Coercri {

    class SDLGfxContext : public GfxContext {
    public:
        explicit SDLGfxContext(SDL_Renderer *renderer);
        virtual ~SDLGfxContext();

        virtual void setClipRectangle(const Rectangle &rect);
        virtual void clearClipRectangle();
        virtual Rectangle getClipRectangle() const;

        virtual int getWidth() const;
        virtual int getHeight() const;
        
        virtual void clearScreen(Color col);
        virtual void plotPixel(int x, int y, Color col);
        virtual void drawGraphic(int x, int y, const Graphic &graphic);
        virtual void drawGraphicModulated(int x, int y, const Graphic &graphic, Color col);

        virtual void drawLine(int x1, int y1, int x2, int y2, Color col);
        virtual void drawRectangle(const Rectangle &rect, Color col);
        virtual void fillRectangle(const Rectangle &rect, Color col);

        virtual boost::shared_ptr<PixelArray> takeScreenshot();

    private:
        void loadClipRectangle();

    private:
        SDL_Renderer *renderer;
        Rectangle clip_rectangle;
    };

}

#endif
